@@ -36,7 +36,7 @@ class CommandNSStatus : public Command
 			else if (u2->IsIdentified() && na && na->nc == u2->Account()) /* Nick is identified */
 				source.Reply("STATUS %s %d %s", nickbuf.c_str(), 3, u2->Account()->display.c_str());
 			else if (u2->IsRecognized()) /* Nick is recognised, but NOT identified */
-				source.Reply("STATUS %s %d %s", nickbuf.c_str(), 2, u2->Account() ? u2->Account()->display.c_str() : "");
+				source.Reply("STATUS %s %d %s", nickbuf.c_str(), 2, u2->IsIdentified() ? u2->Account()->display.c_str() : "");
 			else if (!na) /* Nick is online, but NOT a registered */
 				source.Reply("STATUS %s %d %s", nickbuf.c_str(), 0, "");
 			else
