@@ -18,7 +18,7 @@ class MemoServCore : public Module, public MemoServService
 	bool SendMemoMail(NickCore *nc, MemoInfo *mi, Memo *m)
 	{
 		Anope::string subject = Language::Translate(nc, Config->GetBlock("mail")->Get<const Anope::string>("memo_subject").c_str()),
-			message = Language::Translate(Config->GetBlock("mail")->Get<const Anope::string>("memo_message").c_str());
+			message = Language::Translate(nc, Config->GetBlock("mail")->Get<const Anope::string>("memo_message").c_str());
 
 		subject = subject.replace_all_cs("%n", nc->display);
 		subject = subject.replace_all_cs("%s", m->sender);
@@ -100,7 +100,7 @@ class MemoServCore : public Module, public MemoServService
 
 					if (ci->AccessFor(cu->user).HasPriv("MEMO"))
 					{
-						if (cu->user->Account() && cu->user->Account()->HasExt("MEMO_RECEIVE"))
+						if (cu->user->IsIdentified() && cu->user->Account()->HasExt("MEMO_RECEIVE"))
 							cu->user->SendMessage(MemoServ, MEMO_NEW_X_MEMO_ARRIVED, ci->name.c_str(), Config->StrictPrivmsg.c_str(), MemoServ->nick.c_str(), ci->name.c_str(), mi->memos->size());
 					}
 				}
