@@ -329,7 +329,7 @@ void Anope::Init(int ac, char **av)
 		Log(LOG_TERMINAL) << "-v, --version";
 		Log(LOG_TERMINAL) << "";
 		Log(LOG_TERMINAL) << "Further support is available from https://www.anope.org/";
-		Log(LOG_TERMINAL) << "Or visit us on IRC at irc.anope.org #anope";
+		Log(LOG_TERMINAL) << "Or visit us on IRC at irc.teranova.net #anope";
 		throw CoreException();
 	}
 
@@ -482,7 +482,7 @@ void Anope::Init(int ac, char **av)
 		Log(LOG_TERMINAL) << "*** Support resources: Read through the services.conf self-contained";
 		Log(LOG_TERMINAL) << "*** documentation. Read the documentation files found in the 'docs'";
 		Log(LOG_TERMINAL) << "*** folder. Visit our portal located at https://www.anope.org/. Join";
-		Log(LOG_TERMINAL) << "*** our support channel on /server irc.anope.org channel #anope.";
+		Log(LOG_TERMINAL) << "*** our support channel on /server irc.teranova.net channel #anope.";
 		throw CoreException("Configuration file failed to validate");
 	}
 
